NUIMapPolyline class
- Inheritance
-
- Object
- NUIMapComponent
- NUIMapPolyline
Constructors
-
NUIMapPolyline({String? id, List<
NUILatLng> ? points, bool? visible, int? width, Color? color, VoidCallback? onTap, int? zIndex, bool? geodesic, bool? consumeTapEvents})
Properties
- color → Color?
-
final
- consumeTapEvents → bool?
-
final
- geodesic → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pairinherited
- onTap → VoidCallback?
-
final
-
points
→ List<
NUILatLng> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool?
-
final
- width → int?
-
final
- zIndex → int?
-
final
Methods
-
getMapPosition(
) → LatLng -
override
-
getPolyline(
) → Polyline -
getPolylineLatLng(
) → List< LatLng> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited